# 🧟 Necromancy

Hi, 

This is a package uploaded by the Go Emeritus, Inc. organization. 

The purpose for registering the namespace is to avoid public users accidentally creating or bad actors intentially creating packages that conflict with the packages in the organization's internal private repos, and to reduce the potential for a security breach.

If you have any questions or concerns, please reach out to:
- apostolos@goemeritus.com


